function NuDen_2nd,instruct,indata,row=row

;+
; NAME
;	NuDen_2nd
; PURPOSE
;	To make a second-order leak correction for exposures that
;	use the NuDen filter.  Such exposures, with DPE= 7 or 8,
;	in the second half of CY2001.
; PROCEDURE
;	Average of rows 12/res through 42/res is subtracted from every
;	row in the image.
; CALLING SEQUENCE
;	better=NuDen_2nd(instruct,indata,row=row)
; INPUT
;	instruct, SXT index structure
;	indata, sxt_prep'd image or data cube
; OUTPUT
;	data with NuDen second-order leak correction applied.
; OPTIONAL KEYWORD OUTPUT
;	row, the correction vector (used by sxt_deleak)
; RESTRICTIONS
;	indata must be integer, longword, or floating point.
;	Correction will only be applied to images utilizing
;	the neutral density filter.
; HISTORY
;	 1-Apr-2001 LWA  (Not an April Fool joke!)
;-

out=indata
sz=size(indata)
typ=sz(n_elements(sz)-2)
oktyp=[2,3,4]		;Acceptable data types.
gg=where(typ eq oktyp,ngg)
okdpe=[0,1,3,5,6,7,8]	;DPEs using NuDen filter.

if ngg then begin
   xx=sz(1)-1
   if n_elements(sz) eq 5 then nn=0 else nn=sz(3)-1
   for i=0,nn do begin
      ff=where(gt_dpe(instruct(i)) eq okdpe,nff)
      if nff then begin
         res=gt_res(instruct(i))
         y1=12/res & y2=42/res
         row=total(indata(0:xx,y1:y2,i),2)/(y2-y1+1)
         for j=0,sz(2)-1 do begin
            out(*,j,i)=indata(*,j,i)-row
         endfor
      endif
   endfor
endif else begin
   print,'Input data must be integer, longword or floating, returning.'
   return,''
endelse

return,out
end
